RenameDialog class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- RenameDialog
Constructors
-
RenameDialog({Key? key, Widget? title, Widget submitButton(BuildContext context, void callback())?, Widget cancelButton(BuildContext context, void callback())?, Widget middleButton(BuildContext context)?, FocusNode? focusNode, Widget? label, String? hintText, int? maxLines = 1, bool isSelectedAll = false, TextInputType? textInputType, List<
TextInputFormatter> ? inputFormatters, void onChanged(String text)?, void onTap()?, void onSubmitted(String text)?, TextStyle? inputStyle, bool autofocus = false, bool? enabled, String? onTestError(String text)?}) -
const
Properties
- autofocus → bool
-
final
- cancelButton → Widget Function(BuildContext context, void callback())?
-
final
- enabled → bool?
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String?
-
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
- inputStyle → TextStyle?
-
final
- isSelectedAll → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → Widget?
-
final
- maxLines → int?
-
final
- middleButton → Widget Function(BuildContext context)?
-
final
- onChanged → void Function(String text)?
-
final
- onSubmitted → void Function(String text)?
-
final
- onTap → void Function()?
-
final
- onTestError → String? Function(String text)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- submitButton → Widget Function(BuildContext context, void callback())?
-
final
- textInputType → TextInputType?
-
final
- title → Widget?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< RenameDialog> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited